==> libexplain_0.11.D001.orig.tar.gz: libexplain-0.11.D001/test_utime/main.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2008, 2009 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>
#include <libexplain/ac/unistd.h>
#include <libexplain/ac/utime.h>

#include <libexplain/strtol_or_die.h>
#include <libexplain/utime.h>
#include <libexplain/version_print.h>


static void
usage(void)
{
    fprintf(stderr, "Usage: test_utime <pathname> <times>\n");
    fprintf(stderr, "       test_utime -V\n");
    exit(EXIT_FAILURE);
}


int
main(int argc, char **argv)
{
    const char      *pathname;
    struct utimbuf  times;

    for (;;)
    {
        int c = getopt(argc, argv, "V");
        if (c == EOF)
            break;
        switch (c)
        {
        case 'V':
            explain_version_print();
            return EXIT_SUCCESS;

        default:
            usage();
        }
    }
    switch (argc - optind)
    {
    case 3:
        times.modtime = explain_strtol_or_die(argv[optind + 2]);
        times.actime = explain_strtol_or_die(argv[optind + 1]);
        pathname = argv[optind];
        explain_utime_or_die(pathname, &times);
        break;

    case 1:
        pathname = argv[optind];
        explain_utime_or_die(pathname, NULL);
        break;

    default:
        usage();
    }
    return EXIT_SUCCESS;
}

==> libexplain_0.19.D001.orig.tar.gz: libexplain-0.19.D001/test_utime/main.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2008, 2009 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>
#include <libexplain/ac/unistd.h>
#include <libexplain/ac/utime.h>

#include <libexplain/strtol.h>
#include <libexplain/utime.h>
#include <libexplain/version_print.h>


static void
usage(void)
{
    fprintf(stderr, "Usage: test_utime <pathname> <times>\n");
    fprintf(stderr, "       test_utime -V\n");
    exit(EXIT_FAILURE);
}


int
main(int argc, char **argv)
{
    const char      *pathname;
    struct utimbuf  times;

    for (;;)
    {
        int c = getopt(argc, argv, "V");
        if (c == EOF)
            break;
        switch (c)
        {
        case 'V':
            explain_version_print();
            return EXIT_SUCCESS;

        default:
            usage();
        }
    }
    switch (argc - optind)
    {
    case 3:
        times.modtime = explain_strtol_or_die(argv[optind + 2], 0, 0);
        times.actime = explain_strtol_or_die(argv[optind + 1], 0, 0);
        pathname = argv[optind];
        explain_utime_or_die(pathname, &times);
        break;

    case 1:
        pathname = argv[optind];
        explain_utime_or_die(pathname, NULL);
        break;

    default:
        usage();
    }
    return EXIT_SUCCESS;
}
